@@ -1,4 +1,4 @@
-`logL.Mult` <-
+logL.Mult <-
 function (p, y, model=c("GRW", "URW"))
 # calculate logL over multiple sequences
 #  here, y is a list of paleoTS sequences
